@@ -3,8 +3,7 @@ setMethod("elmt", "EL", function(object,
                                  rhs = NULL,
                                  lhs = NULL,
                                  alpha = 0.05,
-                                 control = el_control()) {
-  # p <- if (is(object, "QGLM")) getNumPar(object) - 1L else getNumPar(object)
+                                 control = NULL) {
   if (is(object, "QGLM")) {
     p <- getNumPar(object) - 1L
     pnames <- names(getOptim(object)$par[-getNumPar(object)])
@@ -16,15 +15,19 @@ setMethod("elmt", "EL", function(object,
     "`elmt()` is not applicable to to an empty model." = getDF(object) >= 1L,
     "`elmt()` is not applicable to a model with one parameter." = p != 1L,
     "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
-      isFALSE(is.null(getData(object))),
-    "Invalid `control` specified." = is(control, "ControlEL")
+      isFALSE(is.null(getData(object)))
   )
+  if (is.null(control)) {
+    control <- getControlEL(object)
+  } else {
+    stopifnot("Invalid `control` specified." = is(control, "ControlEL"))
+  }
   h <- validate_hypotheses(rhs, lhs, p, pnames)
   colnames(h$l) <- pnames
   l <- if (is(object, "QGLM")) cbind(h$l, 0) else h$l
   qh <- head(h$q, n = length(h$q) - 1L) + 1L
   qt <- tail(h$q, n = length(h$q) - 1L)
-  coefficients <- lapply(seq_along(qh), \(x) {
+  estimates <- lapply(seq_along(qh), \(x) {
     drop(h$l %*% coef(object))[qh[x]:qt[x]]
   })
   alpha <- validate_alpha(alpha)
@@ -41,8 +44,10 @@ setMethod("elmt", "EL", function(object,
     maxit, maxit_l, tol, tol_l, step, th, getWeights(object)
   )
   new("ELMT",
-    coefficients = coefficients, statistic = out$statistic, df = diff(h$q),
-    pval = out$pval, cv = out$cv, rhs = h$r, lhs = h$l, alpha = alpha,
-    calibrate = "mvchisq"
+    estimates = estimates, statistic = out$statistic, df = diff(h$q),
+    pval = out$pval, cv = out$cv, rhs = h$r, lhs = l, alpha = alpha,
+    calibrate = "mvchisq", weights = getWeights(object),
+    coefficients = getEstimates(object), method = method,
+    data = if (control@keep_data) getData(object) else NULL, control = control
   )
 })
